@@ -42,7 +42,7 @@ namespace gr {
      public:
       fmcomms2_source_impl(struct iio_context *ctx, bool destroy_ctx,
 		    unsigned long long frequency, unsigned long samplerate,
-		    unsigned long decimation, unsigned long bandwidth,
+		    unsigned long bandwidth,
 		    bool ch1_en, bool ch2_en, bool ch3_en, bool ch4_en,
 		    unsigned long buffer_size, bool quadrature, bool rfdc,
 		    bool bbdc, const char *gain1, double gain1_value,
