@@ -27,7 +27,11 @@ import os
 
 try:
     from iio_swig import *
+    from iio_pluto_source_swig import *
+    from iio_pluto_sink_swig import *
 except ImportError:
     dirname, filename = os.path.split(os.path.abspath(__file__))
     __path__.append(os.path.join(dirname, "..", "..", "swig"))
     from iio_swig import *
+    from iio_pluto_source_swig import *
+    from iio_pluto_sink_swig import *
